plot.saw1.window <-
function(inputdataframe) {
	require(abind)
	require(gplots)

	plotSA1WtableWindow <- tktoplevel()
	title <- "ArvoRe - Cost-Effectiveness Analysis"
	tkwm.title(plotSA1WtableWindow,title)
				
	# What plot?
	frametext <- "Plots"
	frameOverall <- tkwidget(plotSA1WtableWindow, "labelframe", borderwidth = 2, relief = "groove", 
							labelanchor = "n", text = frametext)
	frameButton <- tkwidget(plotSA1WtableWindow, "labelframe", borderwidth = 0, relief = "groove")
		
	tkgrid(frameOverall, sticky = "nwe")
	tkgrid(frameButton, sticky = "swe")
		
	# Image setings.
	g.imgHeight <- 480
	g.imgWidth <- 640
		
	# Canvas window configurations
	C.Height <- min(c(g.imgHeight, 768))
	C.Width <- min(c(g.imgWidth, 1024))
	Borderwidth <- 2
		
	# scrollbar objects
	fHscroll <- tkscrollbar(frameOverall, orient="horiz", command = function(...)tkxview(fCanvas,...) )
	fVscroll <- tkscrollbar(frameOverall, command = function(...)tkyview(fCanvas,...) )
	fCanvas <- tkcanvas(frameOverall, relief = "sunken", borderwidth = Borderwidth, 
						width = C.Width, height = C.Height,
						xscrollcommand = function(...)tkset(fHscroll,...), 
						yscrollcommand = function(...)tkset(fVscroll,...)
						)
							
	# Pack the scroll bars.
	tkpack(fHscroll, side = "bottom", fill = "x")
	tkpack(fVscroll, side = "right", fill = "y")
	# Pack the canvas
	tkpack(fCanvas, anchor = "center", side = "right", fill = "both", expand = 1)
				
	# Image file name setings.
	.Filename <- paste(tempdir(),"\\", "grafico.arvoreCE.png", sep="")

	# Distinct treatments
	vtreatments <- union(character(0), as.character(inputdataframe$Node.Name))
	vectortreatmentslooping <- setdiff(vtreatments,vtreatments[1])

	# Initial colors to treatments points
	treatments.colors.plot <- 1:length(vtreatments)
	# The treatments names
	treatments.label.plot <- vtreatments
		
	# Default img type
	img.type <- "png"
	img.quality <- 90
		
	plot.it.to.image <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$ICER))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$ICER
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("ICER  ", Delta, "C/", Delta, "E"))
						graphTitle <- paste(names(dft1)[1]," vs. ICER", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for ICER.", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$ICER
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
			dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$ICER))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$ICER
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("ICER  ", Delta, "C/", Delta, "E"))
						graphTitle <- paste(names(dft1)[1]," vs. ICER", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for ICER.", sep="")
						
						plot(eixoX, eixoY, col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$ICER
						
						points(eixoX, eixoY, col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")

				dev.off()
			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$ICER))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$ICER
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("ICER  ", Delta, "C/", Delta, "E"))
							graphTitle <- paste(names(dft1)[1]," vs. ICER", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for ICER.", sep="")
							
							plot(eixoX, eixoY, col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$ICER
							
							points(eixoX, eixoY, col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")

					dev.off()
				} else {
					# EPS
					postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$ICER))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$ICER
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("ICER  ", Delta, "C/", Delta, "E"))
							graphTitle <- paste(names(dft1)[1]," vs. ICER", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for ICER.", sep="")
							
							plot(eixoX, eixoY, col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$ICER
							
							points(eixoX, eixoY, col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")

					dev.off()

				}
			}
		}
	}
	
	plot.it.to.image.icrcost <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$IcrCost))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$IcrCost
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("IcrCost  ", Delta, "C"))
						graphTitle <- paste(names(dft1)[1]," vs. IcrCost", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Icr. Cost", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$IcrCost
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
			dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$IcrCost))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$IcrCost
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("IcrCost  ", Delta, "C"))
						graphTitle <- paste(names(dft1)[1]," vs. IcrCost", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Icr. Cost", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$IcrCost
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
					dev.off()
			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$IcrCost))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$IcrCost
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("IcrCost  ", Delta, "C"))
							graphTitle <- paste(names(dft1)[1]," vs. IcrCost", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Icr. Cost", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$IcrCost
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
						dev.off()
				} else {
					# EPS
						postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$IcrCost))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$IcrCost
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("IcrCost  ", Delta, "C"))
							graphTitle <- paste(names(dft1)[1]," vs. IcrCost", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Icr. Cost", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$IcrCost
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
						dev.off()
				
				}
			}
		}
	}

	plot.it.to.image.icreff <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$IncrEffec))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$IncrEffec
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("IncrEff  ", Delta, "E"))
						graphTitle <- paste(names(dft1)[1]," vs. IncrEff", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Icr. Eff.", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$IncrEffec
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- rep(0,length(dft1$IncrEffec))
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$IncrEffec
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("IncrEff  ", Delta, "E"))
						graphTitle <- paste(names(dft1)[1]," vs. IncrEff", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Icr. Eff.", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$IncrEffec
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()

			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$IncrEffec))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$IncrEffec
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("IncrEff  ", Delta, "E"))
							graphTitle <- paste(names(dft1)[1]," vs. IncrEff", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Icr. Eff.", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$IncrEffec
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()
				} else {
					# EPS
					postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- rep(0,length(dft1$IncrEffec))
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$IncrEffec
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("IncrEff  ", Delta, "E"))
							graphTitle <- paste(names(dft1)[1]," vs. IncrEff", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Icr. Eff.", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$IncrEffec
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()					
				}

			}
		}
	}
	
	plot.it.to.image.expcost <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Cost
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.Cost
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected Cost"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected Cost", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected Cost.", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Cost
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Cost
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.Cost
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected Cost"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected Cost", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected Cost.", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Cost
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()

			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Cost
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.Cost
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected Cost"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected Cost", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected Cost.", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Cost
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()
				} else {
					# EPS
					postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Cost
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.Cost
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected Cost"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected Cost", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected Cost.", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Cost
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()					
				}

			}
		}
	}

	plot.it.to.image.expeff <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Effectiveness
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.Effectiveness
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected Effectiveness"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected Effectiveness", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected Effectiveness", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Effectiveness
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Effectiveness
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.Effectiveness
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected Effectiveness"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected Effectiveness", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected Effectiveness", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.Effectiveness
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()

			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Effectiveness
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.Effectiveness
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected Effectiveness"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected Effectiveness", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected Effectiveness", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Effectiveness
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()
				} else {
					# EPS
					postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Effectiveness
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.Effectiveness
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected Effectiveness"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected Effectiveness", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected Effectiveness", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.Effectiveness
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()
				}
			}
		}
	}

	plot.it.to.image.expcer <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
			
		if (img.type == "png") {
			png(file=.Filename, width = img.width, height = img.height, bg = "white", restoreConsole = FALSE)
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.C.E.Ratio
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.C.E.Ratio
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected CE Ratio"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected CE Ratio", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected CE Ratio", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.C.E.Ratio
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()
		} else {
			if (img.type == "jpg") {
				jpeg(filename = .Filename, width = img.width, height = img.height,
				     units = "px", pointsize = 12, quality = img.quality, bg = "white",
				     res = NA, restoreConsole = FALSE)								
			
						referencetreatment <- vtreatments[1]
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
					
						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.C.E.Ratio
						
						eixoX4max <- inputdataframe[,1]
						eixoX4max[which(eixoX4max == Inf)] <- NA
						eixoX4max[which(eixoX4max == -Inf)] <- NA
						eixoX4max[is.nan(eixoX4max)] <- NA
						
						eixoY4max <- inputdataframe$Expected.C.E.Ratio
						eixoY4max[which(eixoY4max == Inf)] <- NA
						eixoY4max[which(eixoY4max == -Inf)] <- NA
						eixoY4max[is.nan(eixoY4max)] <- NA
						
						eixoXmax <- max(eixoX4max, na.rm = TRUE)
						eixoXmin <- min(eixoX4max, na.rm = TRUE)
						eixoYmax <- max(eixoY4max, na.rm = TRUE)
						eixoYmin <- min(eixoY4max, na.rm = TRUE)
						
						eixoXlabel <- names(dft1)[1]
						eixoYlabel <- expression(paste("Expected CE Ratio"))
						graphTitle <- paste(names(dft1)[1]," vs. Expected CE Ratio", sep="")
						graphSubTitle <- paste(referencetreatment, " is reference for Expected CE Ratio", sep="")
						
						plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
								xlab=eixoXlabel, ylab=eixoYlabel,
				 				xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
					
					for (i in vectortreatmentslooping) {
						colorused <- which(vectortreatmentslooping == i)[1] + 1
						dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

						eixoX <- dft1[,1]
						eixoY <- dft1$Expected.C.E.Ratio
						
						points(eixoX, eixoY, type="b", col = colorused )
				# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
					}
			
					smartlegend( x="center", y= "top", inset=0,
								legend = c(treatments.label.plot),
								fill=c(treatments.colors.plot),
								bg = "gray")
				dev.off()

			} else {
				if (img.type == "bmp") {
					bmp(filename = .Filename, width = img.width, height = img.height,
						units = "px", pointsize = 12, bg = "white", res = NA,
						restoreConsole = FALSE)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.C.E.Ratio
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.C.E.Ratio
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected CE Ratio"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected CE Ratio", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected CE Ratio", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.C.E.Ratio
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()
				} else {
					# EPS
					postscript(file = .Filename, encoding = "ISOLatin1", family = "URWHelvetica", width = img.width, height = img.height)
				
							referencetreatment <- vtreatments[1]
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == referencetreatment,]
						
							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.C.E.Ratio
							
							eixoX4max <- inputdataframe[,1]
							eixoX4max[which(eixoX4max == Inf)] <- NA
							eixoX4max[which(eixoX4max == -Inf)] <- NA
							eixoX4max[is.nan(eixoX4max)] <- NA
							
							eixoY4max <- inputdataframe$Expected.C.E.Ratio
							eixoY4max[which(eixoY4max == Inf)] <- NA
							eixoY4max[which(eixoY4max == -Inf)] <- NA
							eixoY4max[is.nan(eixoY4max)] <- NA
							
							eixoXmax <- max(eixoX4max, na.rm = TRUE)
							eixoXmin <- min(eixoX4max, na.rm = TRUE)
							eixoYmax <- max(eixoY4max, na.rm = TRUE)
							eixoYmin <- min(eixoY4max, na.rm = TRUE)
							
							eixoXlabel <- names(dft1)[1]
							eixoYlabel <- expression(paste("Expected CE Ratio"))
							graphTitle <- paste(names(dft1)[1]," vs. Expected CE Ratio", sep="")
							graphSubTitle <- paste(referencetreatment, " is reference for Expected CE Ratio", sep="")
							
							plot(eixoX, eixoY, type="b", col = 1, main=graphTitle, sub=graphSubTitle,
									xlab=eixoXlabel, ylab=eixoYlabel,
									xlim=c(eixoXmin, eixoXmax), ylim=c(eixoYmin, eixoYmax))
						
						for (i in vectortreatmentslooping) {
							colorused <- which(vectortreatmentslooping == i)[1] + 1
							dft1 <- inputdataframe[(inputdataframe$Node.Name) == i,]

							eixoX <- dft1[,1]
							eixoY <- dft1$Expected.C.E.Ratio
							
							points(eixoX, eixoY, type="b", col = colorused )
					# 				xlim=c(xmin, xmax), ylim=c(ymin, ymax))
						}
				
						smartlegend( x="center", y= "top", inset=0,
									legend = c(treatments.label.plot),
									fill=c(treatments.colors.plot),
									bg = "gray")
					dev.off()					
				}
			}
		}
	}

	plot.it.to.image.tornado <- function(inputdataframe, treatments.colors.plot,
										treatments.label.plot,
										.Filename, img.type = "png", img.quality = 90,
										img.width = 600, img.height = 600, ...) {
		print(inputdataframe)
		print(treatments.colors.plot)
		print(treatments.label.plot)
		
	}
	
	# Define o tipo de grafico que deve ser exportado {"ICER","IncrCost","IncrEff"}
	saw1plottype <- "ICER"
	assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
			
	plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
								.Filename = .Filename, img.type = img.type,
								img.width = g.imgWidth, img.height = g.imgHeight)
			
	image1 <- tclVar()
	tcl("image","create","photo",image1,file=.Filename)
	tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
	tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
						

	OnExportGraphic <- function(...) {
		# Recebe o tipo do grafico
		saw1plottype <- get("saw1plottype", envir = .EnvironmentArvoRe)
		
		exportImgGraphWindow <- tktoplevel()
		title <- "rvoRe - Exportar Imagem"
		tkwm.title(exportImgGraphWindow,title)
		
		frameOverall <- tkframe(exportImgGraphWindow)
		frameUpper <- tkframe(frameOverall, relief="groove", borderwidth=0)
		frameUpperLeft <- tkframe(frameUpper, relief="groove", borderwidth=2)
		frameUpperRigth <- tkframe(frameUpper, relief="groove", borderwidth=2)
		frameLower <- tkframe(frameOverall, relief="groove", borderwidth=0)
		
		tkgrid( tklabel(frameUpper,text="Image format"),sticky="n", columnspan = 2)
				
		rbValue <- tclVar("jpg")
		QualityValue <- tclVar("90")
				
		rb1 <- tkradiobutton(frameUpper)
		tkconfigure(rb1,variable=rbValue,value="bmp")
		tkgrid(	tklabel(frameUpperLeft,text="Bitmap .bmp "),rb1, sticky = "ne")
				
		rb2 <- tkradiobutton(frameUpper)
		tkconfigure(rb2,variable=rbValue,value="jpg")
		tkgrid(	tklabel(frameUpperLeft,text="Jpeg .jpg "),rb2, sticky = "ne")
				
		rb3 <- tkradiobutton(frameUpper)
		tkconfigure(rb3,variable=rbValue,value="png")
		tkgrid(	tklabel(frameUpperLeft,text="Portable network graphics .png "),rb3, sticky = "ne")

		rb4 <- tkradiobutton(frameUpper)
		tkconfigure(rb4,variable=rbValue,value="eps")
		tkgrid(	tklabel(frameUpperLeft,text="Encapsulated PostScript .eps "),rb4, sticky = "ne")
		
		SliderValueLabel <- tklabel(frameUpperRigth, text = as.character(tclvalue(QualityValue)) )
		sliderlabel <- tklabel(frameUpperRigth, text = "Image quality value : ")
		sliderlabel2 <- tklabel(frameUpperRigth,text = "%")
		tkgrid(sliderlabel, SliderValueLabel, sliderlabel2)
		tkconfigure(SliderValueLabel, textvariable = QualityValue)
		sliderImg <- tkscale(frameUpperRigth, from = 100, to = 1,
		                   showvalue = F, variable = QualityValue,
		                   resolution = 1, orient = "horizontal")
		tkgrid(sliderImg,sticky="ew")
		
	    ### Image size settings ###
		numericSpinBox <- tkwidget(frameUpperRigth, "SpinBox", editable=TRUE, range = c(100,10000,1), width = 5)
		labeldigits <- tklabel(frameUpperRigth,text="Image height")
		tkgrid(labeldigits, numericSpinBox, sticky = "nw", padx = 5, pady = 5)
		tcl(numericSpinBox, "setvalue", paste("@", g.imgHeight,sep = ""))
		
		numericSpinBox2 <- tkwidget(frameUpperRigth, "SpinBox", editable=TRUE, range = c(100,10000,1), width = 5)
		labeldigits <- tklabel(frameUpperRigth,text="Image width")
		tkgrid(labeldigits, numericSpinBox2, sticky = "nw", padx = 5, pady = 5)
		tcl(numericSpinBox2, "setvalue", paste("@", g.imgWidth,sep = ""))
		
		tkgrid(frameUpperLeft, frameUpperRigth,sticky="ns")
		tkgrid(frameUpper,sticky="ns")
		tkgrid(frameLower,sticky="ns")
		
		Onformat <- function() {
			ansVar <- as.character(tclvalue(rbValue))
			if (ansVar != "jpg") {
				tkconfigure(SliderValueLabel, state = "disabled")
				tkconfigure(sliderlabel, state = "disabled")
				tkconfigure(sliderlabel2, state = "disabled")
				tkconfigure(SliderValueLabel, state = "disabled")
				tkconfigure(sliderImg, state = "disabled")
			} else {
				tkconfigure(SliderValueLabel, state = "normal")
				tkconfigure(sliderlabel, state = "normal")
				tkconfigure(sliderlabel2, state = "normal")
				tkconfigure(SliderValueLabel, state = "normal")
				tkconfigure(sliderImg, state = "normal")
			}
		}
				
		OnOK <- function(...)
		{
			
			img.height <- as.numeric(tclvalue(tcl(numericSpinBox,"getvalue")))
			if ((is.numeric(img.height) )&&(!is.na(img.height))) g.imgHeight <- img.height
			
			img.width <- as.numeric(tclvalue(tcl(numericSpinBox2,"getvalue")))
			if ((is.numeric(img.width) )&&(!is.na(img.width))) g.imgWidth <- img.width
			
			ImgFormatselected <- as.character(tclvalue(rbValue))
			ImgQualityselected <- as.numeric(as.character(tclvalue(QualityValue)))
			if (ImgFormatselected == "png") {
				.Filename <- tclvalue(tkgetSaveFile(filetypes="{{Portable network graphics Image Files} {.png}} {{All files} *}"))
				if (!nchar(.Filename))
					tkfocus(plotSA1WtableWindow)
				else {
					ans <- substr(.Filename,nchar(.Filename)-3,nchar(.Filename))
					if ( ans != ".png" ) .Filename <- paste(.Filename, ".png", sep="")
							
					if (!file.exists(.Filename)) file.remove(.Filename)
					
					if (saw1plottype == "ICER") {
						plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					} else if (saw1plottype == "IncrCost") {
						plot.it.to.image.icrcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					} else if (saw1plottype == "IncrEff") {
						plot.it.to.image.icreff(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					} else if (saw1plottype == "ExpCER") {
						plot.it.to.image.expcer(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					} else if (saw1plottype == "ExpCost") {
						plot.it.to.image.expcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					} else if (saw1plottype == "ExpEff") {
						plot.it.to.image.expeff(inputdataframe, treatments.colors.plot, treatments.label.plot,
													.Filename = .Filename, img.type = img.type,
													img.width = g.imgWidth, img.height = g.imgHeight)
					}
						
				}
			} else {
				if (ImgFormatselected == "jpg") {
					.Filename <- tclvalue(tkgetSaveFile(filetypes="{{Jpeg Image Files} {.jpg}} {{All files} *}"))
					if (!nchar(.Filename))
						tkfocus(plotSA1WtableWindow)
					else {
						ans <- substr(.Filename,nchar(.Filename)-3,nchar(.Filename))
						if ( ans != ".jpg" ) .Filename <- paste(.Filename, ".jpg", sep="")
										
						if (!file.exists(.Filename)) file.remove(.Filename)
								
						if (saw1plottype == "ICER") {
							plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						} else if (saw1plottype == "IncrCost") {
							plot.it.to.image.icrcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						} else if (saw1plottype == "IncrEff") {
							plot.it.to.image.icreff(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						} else if (saw1plottype == "ExpCER") {
							plot.it.to.image.expcer(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						} else if (saw1plottype == "ExpCost") {
							plot.it.to.image.expcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						} else if (saw1plottype == "ExpEff") {
							plot.it.to.image.expeff(inputdataframe, treatments.colors.plot, treatments.label.plot,
														.Filename = .Filename, img.type = img.type,
														img.width = g.imgWidth, img.height = g.imgHeight)
						}
						
					}
				} else {
					if (ImgFormatselected == "bmp") {
						.Filename <- tclvalue(tkgetSaveFile(filetypes="{{Bitmap Image Files} {.bmp}} {{All files} *}"))
						if (!nchar(.Filename))
							tkfocus(plotSA1WtableWindow)
						else {
							ans <- substr(.Filename,nchar(.Filename)-3,nchar(.Filename))
							if ( ans != ".bmp" ) .Filename <- paste(.Filename, ".bmp", sep="")
									
							if (!file.exists(.Filename)) file.remove(.Filename)
							
							if (saw1plottype == "ICER") {
								plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "IncrCost") {
								plot.it.to.image.icrcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "IncrEff") {
								plot.it.to.image.icreff(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpCER") {
								plot.it.to.image.expcer(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpCost") {
								plot.it.to.image.expcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpEff") {
								plot.it.to.image.expeff(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							}
							
						}
					} else {
						# EPS
						.Filename <- tclvalue(tkgetSaveFile(filetypes="{{Encapsulated PostScript Files} {.eps}} {{All files} *}"))
						if (!nchar(.Filename)) {
							tkfocus(plotSA1WtableWindow)
						} else {
							ans <- substr(.Filename,nchar(.Filename)-3,nchar(.Filename))
							if ( ans != ".eps" ) .Filename <- paste(.Filename, ".eps", sep="")
									
							if (!file.exists(.Filename)) file.remove(.Filename)
							
							if (saw1plottype == "ICER") {
								plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "IncrCost") {
								plot.it.to.image.icrcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "IncrEff") {
								plot.it.to.image.icreff(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpCER") {
								plot.it.to.image.expcer(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpCost") {
								plot.it.to.image.expcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							} else if (saw1plottype == "ExpEff") {
								plot.it.to.image.expeff(inputdataframe, treatments.colors.plot, treatments.label.plot,
															.Filename = .Filename, img.type = img.type,
															img.width = g.imgWidth, img.height = g.imgHeight)
							}
						}
					}
				}
			}
			tkdestroy(exportImgGraphWindow)
			tkwm.deiconify(plotSA1WtableWindow)
			tkfocus(plotSA1WtableWindow)
		}
		
						
		OnCancel <- function()
		{
			tkdestroy(exportImgGraphWindow)
			tkwm.deiconify(plotSA1WtableWindow)
			tkfocus(plotSA1WtableWindow)
		}
				
		.Width.but <- 10
		.Height.but <- 1
				
		OK.but <-tkbutton(frameLower,text="OK", width=.Width.but, height=.Height.but, command=OnOK)
		tkbind(exportImgGraphWindow, "<Return>",OnOK)
		Cancel.but <-tkbutton(frameLower,text="Cancel", width=.Width.but, height=.Height.but, command=OnCancel)
		tkbind(exportImgGraphWindow, "<Escape>",OnCancel)
		tkgrid(OK.but, Cancel.but, sticky = "s", padx = 5, pady = 5, columnspan = 2, sticky = "s")
			
		tkbind(rb1, "<Enter>",Onformat)
		tkbind(rb2, "<Enter>",Onformat)
		tkbind(rb3, "<Enter>",Onformat)
		tkbind(rb4, "<Enter>",Onformat)
		tkbind(rb1, "<Leave>",Onformat)
		tkbind(rb2, "<Leave>",Onformat)
		tkbind(rb3, "<Leave>",Onformat)
		tkbind(rb4, "<Leave>",Onformat)
		
		tkgrid(frameOverall)
		tkfocus(exportImgGraphWindow)
# 		posiciona.janela.no.mouse(exportImgGraphWindow)
	}
	
	
	OnGraphIncrCost <- function(...) {
		saw1plottype <- "IncrCost"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)

		plot.it.to.image.icrcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphIncrEff <- function(...) {
		saw1plottype <- "IncrEff"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
		
		plot.it.to.image.icreff(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphICER <- function(...) {
		saw1plottype <- "ICER"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
		
		plot.it.to.image(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphExpCost <- function(...) {
		saw1plottype <- "ExpCost"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)

		plot.it.to.image.expcost(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphExpEff <- function(...) {
		saw1plottype <- "ExpEff"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
		
		plot.it.to.image.expeff(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphExpCER <- function(...) {
		saw1plottype <- "ExpCER"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
		
		plot.it.to.image.expcer(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}
	
	OnGraphTornado <- function(...) {
		saw1plottype <- "Tornado"
		assign("saw1plottype", saw1plottype, .EnvironmentArvoRe)
		
		plot.it.to.image.tornado(inputdataframe, treatments.colors.plot, treatments.label.plot,
									.Filename = .Filename, img.type = img.type,
									img.width = g.imgWidth, img.height = g.imgHeight)
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(fCanvas, "image", g.imgWidth/2, g.imgHeight/2, image = image1, anchor = "center")
		tkconfigure(fCanvas, scrollregion = c(0,0,g.imgWidth,g.imgHeight))
			
	}

	OnOK <- function() {
		file.remove(.Filename)	
		tkdestroy(plotSA1WtableWindow)
		tkfocus(tt)
	}
			
	OnCancel <- function() {
		tkdestroy(plotSA1WtableWindow)
		file.remove(.Filename)	
	#	tkwm.deiconify(tt)
		tkfocus(tt)
	}
	    
	.Width.but <- 10
	.Height.but <- 1
	
	ICER.but <- tkbutton(frameButton,text="ICER", width=.Width.but, height=.Height.but, command=function(...) OnGraphICER(...))
	ICost.but <- tkbutton(frameButton,text="Incr. Cost.", width=.Width.but, height=.Height.but, command=function(...) OnGraphIncrCost(...))
	IEffe.but <- tkbutton(frameButton,text="Incr. Eff.", width=.Width.but, height=.Height.but, command=function(...) OnGraphIncrEff(...))

	ECER.but <- tkbutton(frameButton,text="Expected CER", width=.Width.but, height=.Height.but, command=function(...) OnGraphExpCER(...))
	ECost.but <- tkbutton(frameButton,text="Expected Cost.", width=.Width.but, height=.Height.but, command=function(...) OnGraphExpCost(...))
	EEffe.but <- tkbutton(frameButton,text="Expected Eff.", width=.Width.but, height=.Height.but, command=function(...) OnGraphExpEff(...))
	
	Tornado.but <- tkbutton(frameButton,text="Tornado", width=.Width.but, height=.Height.but, command=function(...) OnGraphTornado(...))

	tkgrid(ICER.but, ICost.but, IEffe.but, ECER.but, ECost.but, EEffe.but,  sticky = "s", padx = 5, pady = 5)
			
	OK.but <- tkbutton(frameButton,text="OK", width=.Width.but, height=.Height.but, command=OnOK)
	Cancel.but <- tkbutton(frameButton,text="Cancel", width=.Width.but, height=.Height.but, command=OnCancel)
	Export.but <- tkbutton(frameButton,text="Export", width=.Width.but, height=.Height.but, command=OnExportGraphic)
	
	tkgrid(OK.but, Cancel.but, Export.but, sticky = "s", padx = 5, pady = 5)
	tkbind(plotSA1WtableWindow, "<Return>",OnOK)
	tkbind(plotSA1WtableWindow, "<Escape>",OnOK)
		
# 	posiciona.janela.no.mouse(plotSA1WtableWindow, 300, 180)
		
	tkfocus(plotSA1WtableWindow)

}
